@@ -105,6 +105,9 @@ define ([
             len = arr ? arr.length : 0;
             console.log("arr has " + len + " members");
             max = arr.reduce(function(prevVal, elem) {
+                if (elem.text === null) {
+                    elem.text = '';
+                }
                 if (elem.text.length > prevVal) {
                     prevVal = elem.text.length;
                 }
@@ -336,8 +339,8 @@ define ([
             // r += appLib.fillNoticesLine();
             r += '</div>';
             if (cf('displaySessionData') === true) {
-                r += 'Session: &nbsp&nbsp' + cf('sessionID') + '<br>';
-                r += 'Last seen: ' + cf('sessionLastSeen') + '<br>';
+                r += 'Plack session ID: ' + cf('sessionID');
+                r += ' (last_seen ' + cf('sessionLastSeen') + ')</br>';
             }
             return r;
         }, // body
@@ -394,11 +397,16 @@ define ([
                 // determine characters needed for padding (based on longest
                 // entry)
                 if (dfo.entriesRead !== undefined) {
+                    console.log("entriesRead", dfo.entriesRead);
                     allEntries = lib.forceArray(dfo.entriesRead);
                 }
                 if (dfo.entriesWrite !== undefined) {
-                    allEntries = allEntries.concat(dfo.entriesWrite);
+                    console.log("entriesWrite", dfo.entriesWrite);
+                    allEntries = allEntries.concat(
+                        dfo.entriesWrite === null ? [] : dfo.entriesWrite
+                    );
                 }
+                console.log("About to call maxLength() on allEntries", allEntries);
                 needed = maxLength(allEntries) + 2;
 
                 // READ-ONLY entries first
@@ -406,7 +414,11 @@ define ([
                 console.log("Processing " + len + "read-only dform entries");
                 for (i = 0; i < len; i += 1) {
                     entry = dfo.entriesRead[i];
-                    if (lib.privCheck(entry.aclProfileRead)) {
+                    if (entry.name === 'divider') {
+                        r += Array(entry.maxlen).join(entry.text) + '<br>';
+                    } else if (entry.name === 'emptyLine') {
+                        r += '<br>';
+                    } else if (lib.privCheck(entry.aclProfileRead)) {
                         r += lib.rightPadSpaces(entry.text.concat(':'), needed);
                         r += '<span id="' + entry.name + '">';
                         r += valueToDisplay(obj, entry.prop);
