@@ -50,7 +50,7 @@ define ([
             'menuText': 'Demo menu',
             'title': 'Demo menu',
             'aclProfile': 'passerby',
-            'entries': ['demoActionFromMenu', 'demoNotice', 'demoSubmenu' ],
+            'entries': ['demoActionFromMenu', 'demoNotice', 'demoSubmenu'],
             'back': 'logout'
         });
 
@@ -61,11 +61,10 @@ define ([
             'title': 'Demo submenu',
             'aclProfile': 'passerby',
             'entries': ['demoActionFromSubmenu', 'demoForm', 'demoBrowser',
-                        'demoTable'],
+                        'demoTable', 'demoRowselect'],
             'back': 'demoMenu'
         });
 
-
     };
 
 });
